@@ -1,15 +1,17 @@
+"""Send a desktop notification
+
+See also aio_notify.py, which does the same with the higher-level Proxy API.
+"""
 import asyncio
 
 from jeepney import DBusAddress, new_method_call
-from jeepney.integrate.asyncio import connect_and_authenticate
+from jeepney.io.asyncio import open_dbus_router
 
 notifications = DBusAddress('/org/freedesktop/Notifications',
                             bus_name='org.freedesktop.Notifications',
                             interface='org.freedesktop.Notifications')
 
 async def send_notification():
-    (transport, protocol) = await connect_and_authenticate(bus='SESSION')
-
     msg = new_method_call(notifications, 'Notify', 'susssasa{sv}i',
                             ('jeepney_test',  # App name
                              0,     # Not replacing any previous notification
@@ -20,8 +22,9 @@ async def send_notification():
                              -1,      # expire_timeout (-1 = default)
                             ))
     # Send the message and await the reply
-    reply = await protocol.send_message(msg)
-    print('Notification ID:', reply[0])
+    async with open_dbus_router() as router:
+        reply = await router.send_and_get_reply(msg)
+        print('Notification ID:', reply.body[0])
 
 loop = asyncio.get_event_loop()
 loop.run_until_complete(send_notification())
