@@ -5,7 +5,7 @@ https://freedesktop.org/wiki/Specifications/secret-storage-spec/secrets-api-0.1.
 import asyncio
 
 from jeepney import new_method_call, DBusAddress, Properties
-from jeepney.integrate.asyncio import connect_and_authenticate
+from jeepney.io.asyncio import open_dbus_router
 
 secrets = DBusAddress('/org/freedesktop/secrets',
                       bus_name= 'org.freedesktop.secrets',
@@ -15,21 +15,19 @@ login_keyring = DBusAddress('/org/freedesktop/secrets/collection/login',
                             bus_name= 'org.freedesktop.secrets',
                             interface='org.freedesktop.Secret.Collection')
 
-msg = new_method_call(login_keyring, 'SearchItems', 'a{ss}', ({
-                          'user': 'tk2e15',
-                        },)
-                     )
+search_msg = new_method_call(
+    login_keyring, 'SearchItems', 'a{ss}', ({'user': 'tk2e15',},)
+)
 
-async def send_notification():
-    (t, p) = await connect_and_authenticate(bus='SESSION')
+async def query_secrets():
+    async with open_dbus_router() as router:
+        get_collections_msg = Properties(secrets).get('Collections')
+        resp = await router.send_and_get_reply(get_collections_msg)
+        print('Collections:', resp.body[0][1])
 
-    resp = await p.send_message(Properties(secrets).get('Collections'))
-    print('Collections:', resp[0][1])
-
-    resp = await p.send_message(msg)
-    print('Search res:', resp)
+        resp = await router.send_and_get_reply(search_msg)
+        print('Search res:', resp.body)
 
 
-loop = asyncio.get_event_loop()
-loop.run_until_complete(send_notification())
+asyncio.run(query_secrets())
 
